==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property items
 */
public data class FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs(
    public val items: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs> {
    override fun toJava():
        com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs =
        com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs.builder()
            .items(items?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs].
 */
@PulumiTagMarker
public class FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgsBuilder internal
constructor() {
    private var items: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("hqtdbksuhmsxlfgv")
    public suspend fun items(`value`: Output<List<String>>) {
        this.items = value
    }

    @JvmName("qoaggrgulkvvsdcw")
    public suspend fun items(vararg values: Output<String>) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("kpjdrlmxqgrvasex")
    public suspend fun items(values: List<Output<String>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("xcgkodrsndacelrt")
    public suspend fun items(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param values
     */
    @JvmName("kqacavnqgwdrwmtl")
    public suspend fun items(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    internal fun build(): FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs =
        FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs(
            items = items,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property items
 */
public data class FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs(
    public val items: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs> {
    override fun toJava(): com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs =
        com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs.builder()
            .items(items?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs].
 */
@PulumiTagMarker
public class FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgsBuilder internal constructor() {
    private var items: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("wsvagnmsvmowyupi")
    public suspend fun items(`value`: Output<List<String>>) {
        this.items = value
    }

    @JvmName("ffmcknckwblfpjil")
    public suspend fun items(vararg values: Output<String>) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("mkdifxfqspvdgonv")
    public suspend fun items(values: List<Output<String>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ngtplqcnhxaboqpw")
    public suspend fun items(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param values
     */
    @JvmName("ygjnpwvyrsrrvdbf")
    public suspend fun items(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    internal fun build(): FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs =
        FieldLevelEncryptionProfileEncryptionEntitiesItemFieldPatternsArgs(
            items = items,
        )
}
